@@ -1,12 +1,15 @@
 """
 The pytoil gh command.
 
+
 Author: Tom Fleet
-Created: 25/06/2021
+Created: 21/12/2021
 """
 
+from __future__ import annotations
+
+import asyncclick as click
 import httpx
-import typer
 from wasabi import msg
 
 from pytoil.api import API
@@ -14,13 +17,11 @@ from pytoil.cli import utils
 from pytoil.config import Config
 from pytoil.repo import Repo
 
-app = typer.Typer()
 
-
-@app.command()
-def gh(
-    project: str = typer.Argument(..., help="Name of the project to go to on GitHub.")
-) -> None:  # pragma: no cover
+@click.command()
+@click.argument("project", nargs=1)
+@click.pass_obj
+async def gh(config: Config, project: str) -> None:
     """
     Open one of your projects on GitHub.
 
@@ -31,11 +32,14 @@ def gh(
 
     $ pytoil gh my_project
     """
-    config = Config.from_file()
-    utils.warn_if_no_api_creds(config)
+    if not config.can_use_api():
+        msg.warn(
+            "You must set your GitHub username and personal access token to use API"
+            " features.",
+            exits=1,
+        )
 
     api = API(username=config.username, token=config.token)
-
     repo = Repo(
         owner=config.username,
         name=project,
@@ -43,15 +47,12 @@ def gh(
     )
 
     try:
-        exists_remote = repo.exists_remote(api=api)
+        exists = await repo.exists_remote(api)
     except httpx.HTTPStatusError as err:
-        utils.handle_http_status_errors(error=err)
+        utils.handle_http_status_error(err)
     else:
-
-        if not exists_remote:
-            msg.warn(
-                f"{project!r} not found on GitHub! Was it a typo?", spaced=True, exits=1
-            )
+        if not exists:
+            msg.warn(f"Could not find {project!r} on GitHub. Was it a typo?", exits=1)
         else:
-            msg.info(f"Opening {project!r} on GitHub...", spaced=True)
-            typer.launch(url=repo.html_url)
+            msg.info(f"Opening {project!r} on GitHub")
+            click.launch(url=repo.html_url)
