@@ -3,17 +3,17 @@ Module responsible for handling pytoil's programmatic
 interaction with its config file.
 
 Author: Tom Fleet
-Created: 18/06/2021
+Created: 21/12/2021
 """
 
 from __future__ import annotations
 
-from dataclasses import field
 from pathlib import Path
-from typing import List, TypedDict
+from typing import TypedDict
 
-import yaml
-from pydantic.dataclasses import dataclass
+import aiofiles
+import tomlkit
+from pydantic import BaseModel
 
 from pytoil.config import defaults
 
@@ -24,52 +24,33 @@ class ConfigDict(TypedDict):
 
     Exactly the same as the dataclass except projects_dir
     is a str here because that's how it will be brought in
-    when deserialising the yaml file.
+    when deserialising the toml file.
     """
 
     projects_dir: str
     token: str
     username: str
     vscode: bool
-    common_packages: List[str]
-    init_on_new: bool
+    code_bin: str
+    common_packages: list[str]
+    cache_timeout: int
+    git: bool
 
 
-@dataclass
-class Config:
-    """
-    Pydantic dataclass representing pytoil's config.
-
-    Args:
-        projects_dir (Path): Where the user keeps their development
-            projects.
-
-        token (str): The user's GitHub OAUTH personal access token.
-
-        username (str): User's GitHub username.
-
-        vscode (bool): Whether or not the user wants pytoil to use VSCode
-            to auto-open projects.
-
-        common_packages (List[str]): List of common packages the user wants to
-            inject into every python environment pytoil creates. Typically
-            used for linters, formatters etc.
-
-        init_on_new (bool): Whether or not the user wants pytoil to
-            initialise a new git repo when creating a new local project.
-    """
-
+class Config(BaseModel):
     projects_dir: Path = defaults.PROJECTS_DIR
     token: str = defaults.TOKEN
     username: str = defaults.USERNAME
     vscode: bool = defaults.VSCODE
-    common_packages: List[str] = field(default_factory=list)
-    init_on_new: bool = defaults.INIT_ON_NEW
+    code_bin: str = defaults.CODE_BIN
+    common_packages: list[str] = defaults.COMMON_PACKAGES
+    cache_timeout: int = defaults.CACHE_TIMEOUT_SECS
+    git: bool = defaults.GIT
 
     @classmethod
-    def from_file(cls, path: Path = defaults.CONFIG_FILE) -> Config:
+    async def load(cls, path: Path = defaults.CONFIG_FILE) -> Config:
         """
-        Reads in the .pytoil.yml config file and returns
+        Reads in the ~/.pytoil.toml config file and returns
         a populated `Config` object.
 
         Args:
@@ -82,31 +63,14 @@ class Config:
         Raises:
             FileNotFoundError: If config file not found.
         """
-
         try:
-            with open(path, mode="r", encoding="utf-8") as f:
-                config_dict: ConfigDict = yaml.full_load(f)
+            async with aiofiles.open(path, mode="r", encoding="utf-8") as f:
+                content = await f.read()
+                config_dict: ConfigDict = tomlkit.parse(content).get("pytoil")
         except FileNotFoundError:
             raise
         else:
-            return Config.from_dict(config_dict)
-
-    @classmethod
-    def from_dict(cls, config_dict: ConfigDict) -> Config:
-        """
-        Takes in a `ConfigDict` and returns a populated
-        `Config` object.
-
-        Args:
-            config_dict (ConfigDict): Populated `ConfigDict` object.
-
-        Returns:
-            Config: Returned `Config`.
-        """
-
-        # We can do this here because pydantic will handle
-        # all the conversion between types under the hood
-        return Config(**config_dict)  # type: ignore
+            return Config(**config_dict)
 
     @classmethod
     def helper(cls) -> Config:
@@ -121,7 +85,6 @@ class Config:
         Returns:
             Config: Helper config object.
         """
-
         # Typed ignored here because we know we're correct, mypy doesn't like this
         # probably something to do with Config being a pydantic model
         # not a pure python class
@@ -140,11 +103,13 @@ class Config:
             "token": self.token,
             "username": self.username,
             "vscode": self.vscode,
+            "code_bin": self.code_bin,
             "common_packages": self.common_packages,
-            "init_on_new": self.init_on_new,
+            "cache_timeout": self.cache_timeout,
+            "git": self.git,
         }
 
-    def write(self, path: Path = defaults.CONFIG_FILE) -> None:
+    async def write(self, path: Path = defaults.CONFIG_FILE) -> None:
         """
         Overwrites the config file at `path` with the attributes from
         the calling instance.
@@ -153,9 +118,9 @@ class Config:
             path (Path, optional): Config file to overwrite.
                 Defaults to defaults.CONFIG_FILE.
         """
-
-        with open(path, mode="w", encoding="utf-8") as f:
-            yaml.dump(self.to_dict(), f)
+        async with aiofiles.open(path, mode="w", encoding="utf-8") as f:
+            content = tomlkit.dumps({"pytoil": self.to_dict()}, sort_keys=True)
+            await f.write(content)
 
     def can_use_api(self) -> bool:
         """
@@ -166,7 +131,6 @@ class Config:
         Returns:
             bool: True if can use API, else False.
         """
-
         conditions = [
             self.username == "",
             self.username == "This your GitHub username",
