@@ -2,27 +2,32 @@
 Global defaults for pytoil.
 
 Author: Tom Fleet
-Created: 18/06/2021
+Created: 21/12/2021
 """
 
+from __future__ import annotations
 
 import os
 from pathlib import Path
-from typing import List, Set
 
 # Default path for pytoil's config file
-CONFIG_FILE: Path = Path.home().joinpath(".pytoil.yml").resolve()
+CONFIG_FILE: Path = Path.home().joinpath(".pytoil.toml").resolve()
 
 # Valid pytoil config keys
-CONFIG_KEYS: Set[str] = {
+CONFIG_KEYS: set[str] = {
     "projects_dir",
     "token",
     "username",
     "vscode",
     "common_packages",
-    "init_on_new",
+    "git",
 }
 
+# API cache
+CACHE_DIR = Path.home().joinpath(".cache/pytoil")
+CACHE_TIMEOUT_SECS = 120
+
+
 # Pytoil docs URL
 PYTOIL_DOCS_URL: str = "https://followtheprocess.github.io/pytoil/"
 
@@ -31,15 +36,16 @@ PROJECTS_DIR: Path = Path.home().joinpath("Development").resolve()
 TOKEN: str = os.getenv("GITHUB_TOKEN", "")
 USERNAME: str = ""
 VSCODE: bool = False
-COMMON_PACKAGES: List[str] = []
-INIT_ON_NEW: bool = True
+CODE_BIN: str = "code"
+COMMON_PACKAGES: list[str] = []
+GIT: bool = True
 
 # Config Schema
 CONFIG_SCHEMA = """
 
-# The .pytoil.yml config file
+# The .pytoil.toml config file
 
-## projects_dir *(bool)*
+## projects_dir *(str)*
 
 The absolute path to where you keep your development projects
 (e.g. /Users/you/Projects).
@@ -61,6 +67,11 @@ Your GitHub username. Pytoil needs this so it can construct urls to your project
 
 Whether you want pytoil to open projects up using VSCode. This will happen on 'new' and 'checkout'.
 
+## code_bin *(str)*
+
+The name of the VSCode binary. Will differ depending on version installed. Either "code" (default)
+or "code-insiders"
+
 ## common_packages *(List[str])*
 
 A list of python packages to inject into every virtual environment pytoil creates
@@ -69,7 +80,7 @@ A list of python packages to inject into every virtual environment pytoil create
 Any versioning syntax (e.g. mypy>=0.902) will work as expected here as these packages
 are passed straight through to installation tools like pip and conda.
 
-## init_on_new *(bool)*
+## git *(bool)*
 
 Whether or not you want pytoil to create an empty git repo when you make a new project with
 'pytoil new'. This can also be disabled on a per use basis using the '--no-git' flag.
